#
# spec file for package python-alsa
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-alsa
Version:        1.2.14
Release:        1.1
Summary:        Python ALSA binding
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          Development/Libraries/Python
URL:            https://www.alsa-project.org
Source:         %{url}/files/pub/pyalsa/pyalsa-%{version}.tar.bz2
Source1:        %{url}/files/pub/pyalsa/pyalsa-%{version}.tar.bz2.sig
Source2:        COPYING
Source3:        COPYING.LIB
Source4:        %{name}.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  alsa-devel
BuildRequires:  python-rpm-macros
Provides:       pyalsa = %{version}
Obsoletes:      pyalsa < %{version}
%python_subpackages

%description
This package provides the Python binding to ALSA.

%prep
%setup -q -n pyalsa-%{version}
cp %{SOURCE2} %{SOURCE3} .

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install

%files %{python_files}
%license COPYING COPYING.LIB
%{python_sitearch}/*

%changelog
* Tue Apr 15 2025 Takashi Iwai <tiwai@suse.com>
- Update to version 1.2.14:
  * documentation updates
  * IEC958 fixes
  * hctltest1.py: Skip read/write if no values in element
  * alsamixer: fix return value in pyalsamixerelement_getvolumedb()
  * alsaseq: Fix type check in set_time()
  For details, see:
    https://www.alsa-project.org/wiki/Changes_v1.2.13_v1.2.14#alsa-python
* Thu Jun 13 2024 Takashi Iwai <tiwai@suse.com>
- Update to version 1.2.12:
  * Improvements on hcontrol and mixer
  * Fixes for setup.py
  * Segfault fix for alsaseq
  For details, see:
    https://www.alsa-project.org/wiki/Changes_v1.2.11_v1.2.12#alsa-python
* Wed Nov  9 2022 Takashi Iwai <tiwai@suse.com>
- Add keyring
* Wed Jun  1 2022 Takashi Iwai <tiwai@suse.com>
- Update to version 1.2.7:
  * alsaseq: fix 'ext' buffer fill
  * various python3 fixes
* Mon Dec  6 2021 tiwai@suse.de
- Update to version 1.2.6:
  including all previous fixes.  See URL below for details:
    https://alsa-project.org/wiki/Changes_v1.2.5.1_v1.2.6#alsa-python
- Add *.sig file for the tarball
- Drop obsoleted patches
  0001-alsaseq-fix-constant-objects-in-Python-3.patch
  0002-Fix-PyTuple_SET_ITEM-usage-no-return-value.patch
* Thu Dec  2 2021 tiwai@suse.de
- Fix Obsoletes with version comparison
- Backport upstream fixes for python3:
  0001-alsaseq-fix-constant-objects-in-Python-3.patch
  0002-Fix-PyTuple_SET_ITEM-usage-no-return-value.patch
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Use https for URL and SourceURL
* Wed Apr  4 2018 tiwai@suse.de
- Rename to python-alsa package
- Follow the standard single spec for python2 & 3
- Run spec-cleaner
* Wed Apr  4 2018 tiwai@suse.de
- Update to version 1.1.6:
  * Change FSF address (Franklin Street)
  * initial python3 support
  * alsaseq: simplify TCONSTADD
  * hctltest2: use 'hw:0' device instead 'default'
  * common.h: fix InternFromString()
  * fix tp_free() calls, remove wrong PyObject_GC_Del use
  * gitignore: add pyalsa/*.so
  * setup.py: check for the existence of the build directory
  * setup: add some missing fields, add header files from pyalsa to MANIFEST
- Use %%license file tag
* Thu Feb 26 2015 tiwai@suse.de
- Update to pyalsa 1.0.29: fixes included:
  alsaseq: fix memory leaks
  alsaseq: remove dead code in Sequencer_set_clientname()
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Fri Sep  7 2012 tiwai@suse.de
- Updated to version 1.0.26:
  just include previous fixes
* Mon Mar 12 2012 tiwai@suse.de
- Updated to version 1.0.25
  - Add register_poll for alsaseq
  - alsa-python mixer: add poll_fds property
  - ctltest1.py: use new class member names
  - alsamixer: Fix bad PyArg_ParseTuple format strings
- Two backport fixes from upstream:
    Fix get_volume_array() for mono channels
    Fix pyalsa tests for new function names
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Mon Apr 26 2010 tiwai@suse.de
- fixed license tag (for overseen GPLv2 file) (bnc#599559)
- add missing COPYING* files
* Mon Apr 19 2010 tiwai@suse.de
- initial version: 1.0.22
